/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sqoop.model;

import org.junit.Test;

import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

import static junit.framework.Assert.assertEquals;

/**
 *
 */
public class TestMFormList {
  @Test
  public void testGetInputs() {
    List<MForm> forms = new LinkedList<MForm>();

    MIntegerInput intInput = new MIntegerInput("Form1.A", false);
    MMapInput mapInput = new MMapInput("Form1.B", false);

    List<MInput<?>> inputs = new ArrayList<MInput<?>>();
    inputs.add(intInput);
    inputs.add(mapInput);
    forms.add(new MForm("Form1", inputs));

    MStringInput stringInput = new MStringInput("Form2.C", false, (short)3);
    MEnumInput enumInput = new MEnumInput("Form2.D", false, new String[] {"I", "V"});

    inputs = new ArrayList<MInput<?>>();
    inputs.add(stringInput);
    inputs.add(enumInput);
    forms.add(new MForm("Form2", inputs));

    MFormList form = new MFormList(forms);
    assertEquals(intInput, form.getIntegerInput("Form1.A"));
    assertEquals(mapInput, form.getMapInput("Form1.B"));
    assertEquals(stringInput, form.getStringInput("Form2.C"));
    assertEquals(enumInput, form.getEnumInput("Form2.D"));  }
}
